An unofficial wrapper of the Iq Option API. A fork of the 'rrfaria' repository.

DO NOT USE THIS API, IT HAS BEEN MODIFIED FOR PERSONAL, NON-COMMERCIAL USE.

If you need an api for Iqoption, I recommend using 'rrfaria' (https://github.com/iqoptionapi/iqoptionapi).
